from .handler import Handler
from .exceptions import *

__all__ = ['Handler', 'LastFMError', 'RateLimitExceeded', 'InvalidAPIKey', 'ArtistNotFoundError', 'AlbumNotFoundError', 'TrackNotFoundError', 'UserNotFoundError']

__version__ = '1.0.0'
__author__ = 'Claqz'
__license__ = 'MIT'
